/*! 
    \file skybox.h
    \brief Definition of the SkyBox, that handles the Display of an atmosphere for orxonox.

    A SkyBox is always centered at the current working Camera, and will only obey the cameras
    movment but not its rotation.
*/

#ifndef _SKYBOX_H
#define _SKYBOX_H

/* INCLUDES */
#include "world_entity.h"

/* FORWARD DEFINITION */
class Material;
class Vector;

//! A Class to handle a Skybox
class SkyBox : public WorldEntity
{

 public:
  SkyBox(char* fileName = NULL);
  virtual ~SkyBox();

  void setSize(float size);
  void setTexture(const char* name, const char* extension);
  void setTextures(const char* top, const char* bottom, const char* left, const char* right, const char* front, const char* back);

 private:
  void rebuild();
  

  Material **material;    //!< A Material for the Skybox.
  float size;       //!< Radius of the Skybox. This should match the frustum maximum range.
    
};

#endif  /* _SKYBOX_H */



